@@ -492,19 +492,24 @@ else
     echo "✓ Node.js already installed: $(node -v)"
 fi
 
-# Download xterm.js files
-echo "Downloading xterm.js..."
+# Download xterm.js files and sync to web root
+echo "Downloading xterm.js files..."
 chmod +x /root/whp/scripts/download-xterm.sh
-/root/whp/scripts/download-xterm.sh
-
-# Sync web files including xterm.js to document root
-echo "Syncing xterm.js files to web root..."
-rsync -av /root/whp/web-files/js/xterm/ /docker/whp/web/js/xterm/
+if ! /root/whp/scripts/download-xterm.sh; then
+    echo "Error: Failed to download xterm.js files"
+    exit 1
+fi
+echo "✓ xterm.js files downloaded and synced successfully"
 
 # Install terminal server dependencies
 echo "Installing terminal server dependencies..."
 cd /root/whp/terminal-server
-npm install --production
+if ! npm install --production; then
+    echo "Error: Failed to install terminal server dependencies"
+    echo "Check that build dependencies are installed and Node.js is working"
+    exit 1
+fi
+echo "✓ Terminal server dependencies installed successfully"
 
 # Copy Apache WebSocket configuration
 echo "Configuring Apache WebSocket proxy..."
@@ -513,10 +518,24 @@ cp /root/whp/configs/whp-terminal-websocket.conf /etc/httpd/conf.d/
 # Install and enable systemd service
 echo "Installing terminal server service..."
 chmod +x /root/whp/scripts/create-terminal-service.sh
-/root/whp/scripts/create-terminal-service.sh
+if ! /root/whp/scripts/create-terminal-service.sh; then
+    echo "Error: Failed to create terminal service"
+    exit 1
+fi
+
 systemctl daemon-reload
-systemctl enable whp-terminal
-systemctl start whp-terminal
+if ! systemctl enable whp-terminal; then
+    echo "Error: Failed to enable terminal service"
+    exit 1
+fi
+
+if ! systemctl start whp-terminal; then
+    echo "Error: Failed to start terminal service"
+    echo "Check service logs: journalctl -u whp-terminal -f"
+    exit 1
+fi
+
+echo "✓ Terminal service installed and started successfully"
 
 echo "✓ WebSocket Terminal Server configured"
 cd /root/whp
