@@ -1,9 +1,11 @@
 <?php
-require_once '/docker/whp/web/libs/session_check.php';
-require_once '/docker/whp/web/configs/config.php';
-
 header('Content-Type: application/json');
 
+// Check API permission
+check_api_permission('terminal');
+
+require_once('/docker/whp/web/configs/config.php');
+
 $response = ['success' => false, 'error' => 'Unknown error'];
 
 if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
